Action1()
{
	int colSize;  //VTS selected column size

	
	/***************************************** MANAGING COMPOSITE RECORDS IN VTS **************************************************/
	/*** In this example, we will pull a composite record from the VTS that has the form: 							         	***/
	/*** AccountNumber, First Name, Middle Initial, Last Name, Address, City, State, ZipCode, Home Phone, and Work Phone.    	***/
	/***																													 	***/
	/*** Each data element is separated by a ":"																				***/
	/*** Example VTS Record:																									***/
	/***																														***/
	/***       5454985555555:Stewart:E:Gary:11022 Klingon Way Apt 603:Lithia:FL:33547:813 555-5555:813 444-4444				  	***/
	/***																														***/
	/*** To preserve data, we will then put the data record back into the VTS as the last record in its column.					***/
	/*** We will then split the composite data record's component parts as new parameters:  Userid, Password, and Server.		***/
	/******************************************************************************************************************************/
	
	/*** Get a record from the VTS by column name.  This will remove the record from the VTS (Destructive Read) ***/
	lr_start_transaction("02_GetCompositeData");
	rc = VTS_GetRecord(ColumnName);
	lr_end_transaction("02_GetCompositeData", LR_AUTO);
	if (rc) //If the get fails, we need to abort
	{
		lr_message("The requested VTS data %s column is empty or not found!", ColumnName);
		lr_exit(LR_EXIT_VUSER, LR_FAIL);
	}
	lr_message("Data parameter returned from VTS = %s", lr_eval_string("{Composite}"));  //We have a composite record
	
	
	/*** When we get a record from the VTS and want to reuse the data, we must put the value retrieved back in the VTS as the last record in the column ***/
	lr_start_transaction("03_PutCompositeData");
	rc = VTS_PutRecord(ColumnName, lr_eval_string("{Composite}"));
	lr_end_transaction("03_PutCompositeData", LR_AUTO);
	if (rc) //If the write back to the VTS failed,  something is wrong at the VTS level, abort
	{
		lr_message("VTS Write Failed for Composite!");
		lr_exit(LR_EXIT_VUSER, LR_FAIL);
	}
	lr_message("Composite value was succefully written back to the VTS");
	

	/*** We now have a composite record, split the Composite data into its individual parts. ***/
	lr_start_transaction("04_SplitCompositRecord");
	rc = GetCompositeData(lr_eval_string("{Composite}"));
	lr_end_transaction("04_SplitCompositRecord", LR_AUTO);
	if (rc) 
	{
		lr_message("Invalid Composite Record!");
		lr_exit(LR_EXIT_VUSER, LR_FAIL);
	}
	
	/*** Just display the record from the parameters that were created ***/
	lr_message("Composite record succesfully processed.  Values = %s, %s, %s, %s, %s, %s, %s, %s, %s, %s", 
	           		 lr_eval_string("{AccountNumber}"),
	           		 lr_eval_string("{FirstName}"),
	           		 lr_eval_string("{MI}"),
	           		 lr_eval_string("{LastName}"),
	           		 lr_eval_string("{Address}"),
	           		 lr_eval_string("{City}"),
	           		 lr_eval_string("{State}"),
	           		 lr_eval_string("{ZipCode}"),
	           		 lr_eval_string("{HomePhone}"),
	           		 lr_eval_string("{WorkPhone}"));
	
	return 0;
}