#ifdef COMMENT
********************************************************************
Author: 	Gary E. Stewart
Company: 	Orasi Software, Inc
Contact: 	gary.stewart@orasi.com

Description: 	
 	This script demonstrates how to read composite data from the new VTS Version 12.53.
 		
	The data record is comprised of AccountNumber, First Name, Middle Initial, Last Name, Address, City,
 	State, ZipCode, Home Phone, and Work Phone. Each data element is separated by a ":"
	
 	Example VTS Record:																						
		5454985555555:Stewart:E:Gary:11022 Klingon Way Apt 603:Lithia:FL:33547:813 555-5555:813 444-4444			 

	The global variable ColumnName controls the name of the column where data will be read from the VTS.
 	The global variable VtsServer controls which IP to connect to.
 	The global variable nPort control which port to use when connecting.

********************************************************************
#endif


/************* BEGIN GLOBAL VARIABLES *****************/
char  *VtsServer = "Saturn";					// UNC VTS Server Name or IP
int   nPort = 8888;							// VTS Port as shown as API Access Port in the VTS GUI
int   rc;										// Variable for result code return from VTS calls
int   colSize;  									// VTS selected column size. Used to detect existence of the Column name in the VTS table
char  ColumnName[] = "Composite";			// Name of the VTS Column that we will write to in the VTS
											// Script will abort if this column exists in the VTS.
										
PVCI2 pvci = 0;								// VTS defined data type (Pointer to VTS Instance)
/************* END GLOBAL VARIABLES *****************/

vuser_init()
{
	int colSize;  //VTS selected column size
	
	/*** Connect to the VTS Server ***/
	VTS_Connect();
	
	/***************************************** MANAGING COMPOSITE RECORDS IN VTS ****************/
	/*** In this example, we will pull a composite record from the VTS that has the form: tester003:tester003:CSOIntSev03. 	***/
	/*** We will then put the record back in the VTS as the last record from its column.  We will then split the composite       	***/
	/***  record's component parts as 3 new parameters:  Userid, Password, and Server.                                   				***/
	/*************************************************************************************************/
	
	/*** Get the number of record in the Composite VTS column  ***/
	lr_start_transaction("01_GetColRecordCount");
	colSize =VTS_GetRecordCount(ColumnName);
	lr_end_transaction("01_GetColRecordCount", LR_AUTO);

	if(!colSize)	//If we don't have an records or we are out of data, terminate the script
	{
		lr_error_message("Selected VTS Column is empty or Column not found!");
		lr_error_message("This requires that the VTS be populated.  Please run the VTS_BuildData_Demo script first!");
		lr_exit(LR_EXIT_VUSER, LR_FAIL);
	}
	lr_message("There are %d records in the %s column", colSize, ColumnName);  //We have records available

	return 0;
}
